@@ -18,19 +18,22 @@ no  design    df      df2    steps  bk    bkni
  0  parallel 2*(n-1) 2*(n-1)  1      2    NA
  1  2x2      n-2     n-2      2      2    0.5
  1  2x2x2    n-2     n-2      2      2    0.5
- 2  3x3      2*n-3   n-3      3      2    NA
- 3  4x4      3*n-5   n-4      4      2    NA
- 4  2x2x3    2*n-3   n-2      2      1.5  0.375       # 3/8
- 5  2x2x4    3*n-4   n-2      2      1    0.25        # 1/4
- 6  2x4x4    3*n-4   n-4      4      1    0.0625      # 1/16
+ 2  3x3      2*n-4   n-3      3      2    NA
+ 3  3x6x3    2*n-4   n-6      6      2    NA
+ 4  4x4      3*n-6   n-4      4      2    NA
+ 5  2x2x3    2*n-3   n-2      2      1.5  0.375       # 3/8
+ 6  2x2x4    3*n-4   n-2      2      1    0.25        # 1/4
+ 7  2x4x4    3*n-4   n-4      4      1    0.0625      # 1/16
  9  2x3x3    2*n-3   n-3      3      1.5  0.1666667   # 1/6
 10  2x4x2    n-2     n-2      4      8    0.5
 ")
-# no. 10 is Balaam's design, a mixture of crossover and parallel group.
 # no. 9 is f.i. the partial replicate design TRR/RTR/RRT
+# no. 10 is Balaam's design, a mixture of crossover and parallel group.
 #
 # eventually it would be better to have steps=6 in case of 3x3 (6 seq. design)
-	
+# Jan 2011: 3x6x3 introduced, df for 3x3 corrected (former 2*n-3)
+# also df for 4x4 corrected (former 3*n-5)
+  
   des2 <- textConnection(des)
   designs <- read.table(des2, header=TRUE, sep="", strip.white=TRUE, as.is=TRUE)           
   close(des2)   # without this close() warnings are generated
@@ -53,7 +56,7 @@ no  design    df      df2    steps  bk    bkni
 # design: a character string describing the design
 .design.no <- function(design)
 {
-  #take the first word if more then one
+  #take the first word if more then one f.i. in "parallel group"
   desi <- unlist(strsplit(tolower(design)," "))[1]
 	
   des <- known.designs()
